@@ -16,6 +16,10 @@ class BaseMapper(object):
     def get_target_type_name(self):
         raise NotImplementedError
 
+    # returns a string which will show to the user in the usage, to show him which format you expected to parse
+    def get_expected_input_format(self):
+        return None
+
     # this is the mapping method.
     # you should return the mapped object, or a non object when something wents wrong.
     def map(self, value):
